@@ -27,6 +27,7 @@ def main():
     parser.add_argument('-o', '--output', type=str, required=False)
     parser.add_argument('-d', '--dburl', type=str, default='', required=False)
     parser.add_argument('-f', '--format', type=str, required=False)
+    parser.add_argument('--notice', action='store_true', required=False)
 
     try:
         args = parser.parse_args()
@@ -55,6 +56,19 @@ def main():
     if args.format:  # -f option
         format = args.format
 
+    if args.notice:  # --notice option
+        try:
+            base_path = sys._MEIPASS
+        except Exception:
+            base_path = os.path.dirname(__file__)
+
+        data_path = os.path.join(base_path, 'LICENSES')
+        print(f"*** {_PKG_NAME} open source license notice ***")
+        for ff in os.listdir(data_path):
+            f = open(os.path.join(data_path, ff), 'r', encoding='utf8')
+            print(f.read())
+        sys.exit(0)
+
     timer = TimerThread()
     timer.setDaemon(True)
     timer.start()
